import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/buttons/button-tap.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

/// Indicates if Button size is going to be [Small],[Normal], [Large] or [Xlarge]
enum ButtonSize { SMALL, NORMAL, LARGE, XLARGE }

// Indicates if Button type is going to be [FAB],[PRIMARY] or [ICON]
enum ButtonType { FAB, PRIMARY, ICON }

class Button extends StatefulWidget {
  Color textColor;
  Color color;
  Color? indicatorColor;
  Color? indicatorValueColor;
  Color? borderColor;
  bool? filled;
  double? fontSize;
  bool disabled;

  Widget? buttonIcon;

  ButtonType? type;
  bool? border;

  String? text;
  String? icon;

  ButtonSize? size;
  bool? fullScreen;

  bool? loading;
  bool? hasBeenPressed;

  void Function()? onPressed;

  Button(
      {this.disabled = false,
      this.filled = false,
      this.text = 'Button',
      this.icon = 'assets/img/button-icon.png',
      this.type,
      this.fontSize,
      this.fullScreen = false,
      this.color = kPrimaryBase,
      this.indicatorColor,
      this.indicatorValueColor,
      this.borderColor,
      this.textColor = kPrimaryLighten0,
      this.size = ButtonSize.NORMAL,
      this.border = true,
      this.loading = false,
      this.hasBeenPressed = false,
      this.buttonIcon,
      this.onPressed});
  @override
  _ButtonState createState() => _ButtonState();
}

class _ButtonState extends State<Button> with SingleTickerProviderStateMixin {
  AnimationController? _animationController;
  Animation<double>? _scaleAnimation;
  Duration duration = const Duration(milliseconds: 80);
  double _opacity = 1;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(vsync: this, duration: duration);
    _scaleAnimation =
        Tween<double>(begin: 1, end: 0.94).animate(_animationController!);
  }

  @override
  void dispose() {
    _animationController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    double w = MediaQuery.of(context).size.width;
    return ButtonTap(
      disabled: widget.disabled,
      onTap: widget.loading! || widget.disabled
          ? () {}
          : widget.onPressed ??
              () {
                setState(() {
                  widget.hasBeenPressed = !widget.hasBeenPressed!;
                });
              },
      child: widget.type == ButtonType.FAB
          ? Container(
              // width: w * 0.20,
              // height: w * 0.092,
              decoration: BoxDecoration(
                  color: widget.filled!
                      ? !widget.hasBeenPressed!
                          ? widget.color
                          : kPrimaryLighten4.withOpacity(0.8)
                      : Colors.transparent,
                  borderRadius: BorderRadius.only(
                      topRight: Radius.circular(40),
                      bottomLeft: Radius.circular(40),
                      bottomRight: Radius.circular(40)),
                  border: Border(
                    top: BorderSide(
                      width: 1.5,
                      color: widget.disabled
                          ? kLightNeutralLighten4
                          : widget.color,
                    ),
                    left: BorderSide(
                      width: 1.5,
                      color: widget.disabled
                          ? kLightNeutralLighten4
                          : widget.color,
                    ),
                    right: BorderSide(
                      width: 1.5,
                      color: widget.disabled
                          ? kLightNeutralLighten4
                          : widget.color,
                    ),
                    bottom: BorderSide(
                      width: 1.5,
                      color: widget.disabled
                          ? kLightNeutralLighten4
                          : widget.color,
                    ),
                  )),
              padding: EdgeInsets.all(20.25),
              child: widget.loading!
                  ? Container(
                      child: SizedBox(
                        height: 25,
                        width: 25,
                        child: CircularProgressIndicator(
                          backgroundColor: widget.indicatorColor != null
                              ? widget.indicatorColor!
                              : kLightNeutralLighten0,
                          valueColor: AlwaysStoppedAnimation<Color>(
                              widget.indicatorValueColor != null
                                  ? widget.indicatorValueColor!
                                  : widget.color),
                          strokeWidth: 3,
                        ),
                      ),
                    )
                  : widget.buttonIcon ??
                      Image.asset("assets/img/button-icon-noCircle.png",
                          scale: 2.0,
                          color: !widget.hasBeenPressed! && widget.filled!
                              ? Colors.white
                              : widget.disabled & !widget.filled!
                                  ? kDarkNeutralLighten4
                                  : widget.color),
            )
          : widget.type == ButtonType.ICON
              ? Container(
                  child: widget.buttonIcon ??
                      Image.asset("assets/img/button-icon.png",
                          scale: widget.size == ButtonSize.SMALL
                              ? 2
                              : widget.size == ButtonSize.NORMAL
                                  ? 1.2
                                  : widget.size == ButtonSize.LARGE
                                      ? 1
                                      : widget.size == ButtonSize.XLARGE
                                          ? 0.8
                                          : 1,
                          color: widget.color),
                )
              : widget.size == ButtonSize.SMALL
                  ? Container(
                      width: widget.fullScreen! ? w : null,
                      decoration: BoxDecoration(
                        color: !widget.disabled &&
                                widget.filled! &&
                                (widget.color != kPrimaryBase ||
                                    widget.color != kSuccessBase ||
                                    widget.color != kWarningBase ||
                                    widget.color != kSuccessBase ||
                                    widget.color != kAccentBase)
                            ? widget.color
                            : widget.disabled &&
                                    widget.color == kPrimaryBase &&
                                    widget.filled!
                                ? kDarkNeutralLighten2
                                : widget.disabled &&
                                        widget.color == kSuccessBase &&
                                        widget.filled!
                                    ? kSuccessLighten2
                                    : widget.disabled &&
                                            widget.color == kAccentBase &&
                                            widget.filled!
                                        ? kAccentLighten2
                                        : widget.disabled &&
                                                widget.color == kWarningBase &&
                                                widget.filled!
                                            ? kWarningLighten2
                                            : widget.disabled &&
                                                    widget.color ==
                                                        kErrorBase &&
                                                    widget.filled!
                                                ? kErrorLighten2
                                                : widget.filled! &&
                                                        widget.hasBeenPressed!
                                                    ? widget.color
                                                    : widget.color ==
                                                                kPrimaryBase &&
                                                            widget.filled! &&
                                                            !widget
                                                                .hasBeenPressed!
                                                        ? kPrimaryDarken4
                                                        : widget.color ==
                                                                    kSuccessBase &&
                                                                widget
                                                                    .filled! &&
                                                                !widget
                                                                    .hasBeenPressed!
                                                            ? kSuccessDarken4
                                                            : widget.color ==
                                                                        kAccentBase &&
                                                                    widget
                                                                        .filled! &&
                                                                    !widget
                                                                        .hasBeenPressed!
                                                                ? kAccentDarken4
                                                                : widget.color ==
                                                                            kWarningBase &&
                                                                        widget
                                                                            .filled! &&
                                                                        !widget
                                                                            .hasBeenPressed!
                                                                    ? kWarningDarken4
                                                                    : widget.color ==
                                                                                kErrorBase &&
                                                                            widget
                                                                                .filled! &&
                                                                            !widget
                                                                                .hasBeenPressed!
                                                                        ? kErrorDarken4
                                                                        : widget.filled! &&
                                                                                widget.disabled
                                                                            ? kDarkNeutralLighten2
                                                                            : Colors.transparent,
                        border: widget.border!
                            ? Border(
                                top: BorderSide(
                                  width: 1.0,
                                  color: widget.disabled && !widget.filled!
                                      ? kDarkNeutralLighten4
                                      : widget.color,
                                ),
                                left: BorderSide(
                                  width: 1.0,
                                  color: widget.disabled && !widget.filled!
                                      ? kDarkNeutralLighten4
                                      : widget.color,
                                ),
                                right: BorderSide(
                                  width: 1.0,
                                  color: widget.disabled && !widget.filled!
                                      ? kDarkNeutralLighten4
                                      : widget.color,
                                ),
                                bottom: BorderSide(
                                  width: 1.0,
                                  color: widget.disabled && !widget.filled!
                                      ? kDarkNeutralLighten4
                                      : widget.color,
                                ),
                              )
                            : Border(),
                        borderRadius: widget.filled!
                            ? BorderRadius.only(
                                topLeft: Radius.circular(20),
                                topRight: Radius.circular(20),
                                bottomLeft: Radius.circular(20),
                                bottomRight: Radius.circular(20))
                            : BorderRadius.only(
                                topRight: Radius.circular(24),
                                bottomLeft: Radius.circular(24),
                                bottomRight: Radius.circular(24),
                                topLeft: Radius.circular(24)),
                      ),
                      padding: EdgeInsets.symmetric(horizontal: 8, vertical: 4),
                      child: widget.loading!
                          ? Container(
                              padding: EdgeInsets.symmetric(
                                  horizontal: 14, vertical: 2),
                              child: SizedBox(
                                height: 15,
                                width: 15,
                                child: widget.fullScreen!
                                    ? Center(
                                        child: CircularProgressIndicator(
                                          backgroundColor:
                                              widget.indicatorColor != null
                                                  ? widget.indicatorColor!
                                                  : kLightNeutralLighten0,
                                          valueColor: AlwaysStoppedAnimation<
                                                  Color>(
                                              widget.indicatorValueColor != null
                                                  ? widget.indicatorValueColor!
                                                  : widget.color),
                                          strokeWidth: 1,
                                        ),
                                      )
                                    : CircularProgressIndicator(
                                        backgroundColor:
                                            widget.indicatorColor != null
                                                ? widget.indicatorColor!
                                                : kLightNeutralLighten0,
                                        valueColor:
                                            AlwaysStoppedAnimation<Color>(widget
                                                        .indicatorValueColor !=
                                                    null
                                                ? widget.indicatorValueColor!
                                                : widget.color),
                                        strokeWidth: 1,
                                      ),
                              ),

                              // color: Colors.red
                            )
                          : Row(
                              mainAxisSize: MainAxisSize.min,
                              mainAxisAlignment: widget.fullScreen!
                                  ? MainAxisAlignment.center
                                  : MainAxisAlignment.start,
                              children: [
                                widget.icon != ''
                                    ? Image.asset(widget.icon!,
                                        scale: 7,
                                        color: widget.filled!
                                            ? kPrimaryLighten0
                                            : !widget.filled! && widget.disabled
                                                ? kDarkNeutralLighten4
                                                : widget.color)
                                    : SizedBox(),
                                widget.icon != ''
                                    ? SizedBox(
                                        width: 11,
                                      )
                                    : SizedBox(),
                                Flexible(
                                  child: Text(
                                    widget.text!,
                                    textAlign: TextAlign.center,
                                    style: TextStyle(
                                        color: widget.disabled && widget.filled!
                                            ? kLightNeutralLighten0
                                            : widget.disabled && !widget.filled!
                                                ? kDarkNeutralLighten4
                                                : widget.filled!
                                                    ? widget.textColor
                                                    : widget.color,
                                        fontSize: widget.fontSize ?? 9,
                                        fontWeight: FontWeight.w500,
                                        fontFamily: "Poppins",
                                        decoration: TextDecoration.none),
                                  ),
                                )
                              ],
                            ),
                    )
                  : widget.size == ButtonSize.NORMAL
                      ? Container(
                          width: widget.fullScreen! ? w : null,
                          decoration: BoxDecoration(
                            color: !widget.disabled &&
                                    widget.filled! &&
                                    (widget.color != kPrimaryBase ||
                                        widget.color != kSuccessBase ||
                                        widget.color != kWarningBase ||
                                        widget.color != kSuccessBase ||
                                        widget.color != kAccentBase)
                                ? widget.color
                                : widget.disabled &&
                                        widget.color == kPrimaryBase &&
                                        widget.filled!
                                    ? kDarkNeutralLighten2
                                    : widget.disabled &&
                                            widget.color == kSuccessBase &&
                                            widget.filled!
                                        ? kSuccessLighten2
                                        : widget.disabled &&
                                                widget.color == kAccentBase &&
                                                widget.filled!
                                            ? kAccentLighten2
                                            : widget.disabled &&
                                                    widget.color ==
                                                        kWarningBase &&
                                                    widget.filled!
                                                ? kWarningLighten2
                                                : widget.disabled &&
                                                        widget.color ==
                                                            kErrorBase &&
                                                        widget.filled!
                                                    ? kErrorLighten2
                                                    : widget.filled! &&
                                                            widget
                                                                .hasBeenPressed!
                                                        ? widget.color
                                                        : widget.color ==
                                                                    kPrimaryBase &&
                                                                widget
                                                                    .filled! &&
                                                                !widget
                                                                    .hasBeenPressed!
                                                            ? kPrimaryDarken4
                                                            : widget.color ==
                                                                        kSuccessBase &&
                                                                    widget
                                                                        .filled! &&
                                                                    !widget
                                                                        .hasBeenPressed!
                                                                ? kSuccessDarken4
                                                                : widget.color ==
                                                                            kAccentBase &&
                                                                        widget
                                                                            .filled! &&
                                                                        !widget
                                                                            .hasBeenPressed!
                                                                    ? kAccentDarken4
                                                                    : widget.color ==
                                                                                kWarningBase &&
                                                                            widget
                                                                                .filled! &&
                                                                            !widget
                                                                                .hasBeenPressed!
                                                                        ? kWarningDarken4
                                                                        : widget.color == kErrorBase &&
                                                                                widget.filled! &&
                                                                                !widget.hasBeenPressed!
                                                                            ? kErrorDarken4
                                                                            : widget.filled! && widget.disabled
                                                                                ? kDarkNeutralLighten2
                                                                                : Colors.transparent,
                            border: widget.border!
                                ? Border(
                                    top: BorderSide(
                                      width: 1.0,
                                      color: widget.disabled && !widget.filled!
                                          ? kDarkNeutralLighten4
                                          : widget.color,
                                    ),
                                    left: BorderSide(
                                      width: 1.0,
                                      color: widget.disabled && !widget.filled!
                                          ? kDarkNeutralLighten4
                                          : widget.color,
                                    ),
                                    right: BorderSide(
                                      width: 1.0,
                                      color: widget.disabled && !widget.filled!
                                          ? kDarkNeutralLighten4
                                          : widget.color,
                                    ),
                                    bottom: BorderSide(
                                      width: 1.0,
                                      color: widget.disabled && !widget.filled!
                                          ? kDarkNeutralLighten4
                                          : widget.color,
                                    ),
                                  )
                                : Border(),
                            borderRadius: widget.filled!
                                ? BorderRadius.only(
                                    topLeft: Radius.circular(20),
                                    topRight: Radius.circular(20),
                                    bottomLeft: Radius.circular(20),
                                    bottomRight: Radius.circular(20))
                                : BorderRadius.only(
                                    topRight: Radius.circular(24),
                                    bottomLeft: Radius.circular(24),
                                    bottomRight: Radius.circular(24),
                                    topLeft: Radius.circular(24)),
                          ),
                          padding:
                              EdgeInsets.symmetric(horizontal: 12, vertical: 8),
                          child: widget.loading!
                              ? Container(
                                  padding: EdgeInsets.symmetric(
                                      horizontal: 18, vertical: 2),
                                  child: SizedBox(
                                    height: 20,
                                    width: 20,
                                    child: widget.fullScreen!
                                        ? Center(
                                            child: CircularProgressIndicator(
                                            backgroundColor:
                                                widget.indicatorColor != null
                                                    ? widget.indicatorColor!
                                                    : kLightNeutralLighten0,
                                            valueColor: AlwaysStoppedAnimation<
                                                Color>(widget
                                                        .indicatorValueColor !=
                                                    null
                                                ? widget.indicatorValueColor!
                                                : widget.color),
                                            strokeWidth: 3,
                                          ))
                                        : CircularProgressIndicator(
                                            backgroundColor:
                                                widget.indicatorColor != null
                                                    ? widget.indicatorColor!
                                                    : kLightNeutralLighten0,
                                            valueColor: AlwaysStoppedAnimation<
                                                Color>(widget
                                                        .indicatorValueColor !=
                                                    null
                                                ? widget.indicatorValueColor!
                                                : widget.color),
                                            strokeWidth: 3,
                                          ),
                                  ),
                                )
                              : Row(
                                  mainAxisSize: MainAxisSize.min,
                                  mainAxisAlignment: widget.fullScreen!
                                      ? MainAxisAlignment.center
                                      : MainAxisAlignment.start,
                                  children: [
                                    widget.icon != ''
                                        ? Image.asset(widget.icon!,
                                            scale: 3.7,
                                            color: widget.filled!
                                                ? kPrimaryLighten0
                                                : !widget.filled! &&
                                                        widget.disabled
                                                    ? kDarkNeutralLighten4
                                                    : widget.color)
                                        : SizedBox(),
                                    widget.icon != ''
                                        ? SizedBox(
                                            width: 11,
                                          )
                                        : SizedBox(),
                                    Flexible(
                                      child: Text(
                                        widget.text!,
                                        textAlign: TextAlign.center,
                                        style: TextStyle(
                                            color: widget.disabled &&
                                                    widget.filled!
                                                ? kLightNeutralLighten0
                                                : widget.disabled &&
                                                        !widget.filled!
                                                    ? kDarkNeutralLighten4
                                                    : widget.filled!
                                                        ? widget.textColor
                                                        : widget.color,
                                            fontSize: widget.fontSize ?? 16,
                                            fontWeight: FontWeight.w500,
                                            fontFamily: "Poppins",
                                            decoration: TextDecoration.none),
                                      ),
                                    )
                                  ],
                                ),
                        )
                      : widget.size == ButtonSize.LARGE
                          ? Container(
                              width: widget.fullScreen! ? w : null,
                              decoration: BoxDecoration(
                                color: !widget.disabled &&
                                        widget.filled! &&
                                        (widget.color != kPrimaryBase ||
                                            widget.color != kSuccessBase ||
                                            widget.color != kWarningBase ||
                                            widget.color != kSuccessBase ||
                                            widget.color != kAccentBase)
                                    ? widget.color
                                    : widget.disabled &&
                                            widget.color == kPrimaryBase &&
                                            widget.filled!
                                        ? kDarkNeutralLighten2
                                        : widget.disabled &&
                                                widget.color == kSuccessBase &&
                                                widget.filled!
                                            ? kSuccessLighten2
                                            : widget.disabled &&
                                                    widget.color ==
                                                        kAccentBase &&
                                                    widget.filled!
                                                ? kAccentLighten2
                                                : widget.disabled &&
                                                        widget.color ==
                                                            kWarningBase &&
                                                        widget.filled!
                                                    ? kWarningLighten2
                                                    : widget.disabled &&
                                                            widget.color ==
                                                                kErrorBase &&
                                                            widget.filled!
                                                        ? kErrorLighten2
                                                        : widget.filled! &&
                                                                widget
                                                                    .hasBeenPressed!
                                                            ? widget.color
                                                            : widget.color ==
                                                                        kPrimaryBase &&
                                                                    widget
                                                                        .filled! &&
                                                                    !widget
                                                                        .hasBeenPressed!
                                                                ? kPrimaryDarken4
                                                                : widget.color ==
                                                                            kSuccessBase &&
                                                                        widget
                                                                            .filled! &&
                                                                        !widget
                                                                            .hasBeenPressed!
                                                                    ? kSuccessDarken4
                                                                    : widget.color ==
                                                                                kAccentBase &&
                                                                            widget
                                                                                .filled! &&
                                                                            !widget
                                                                                .hasBeenPressed!
                                                                        ? kAccentDarken4
                                                                        : widget.color == kWarningBase &&
                                                                                widget.filled! &&
                                                                                !widget.hasBeenPressed!
                                                                            ? kWarningDarken4
                                                                            : widget.color == kErrorBase && widget.filled! && !widget.hasBeenPressed!
                                                                                ? kErrorDarken4
                                                                                : widget.filled! && widget.disabled
                                                                                    ? kDarkNeutralLighten2
                                                                                    : Colors.transparent,
                                border: widget.border!
                                    ? Border(
                                        top: BorderSide(
                                          width: 1.0,
                                          color: widget.borderColor != null
                                              ? widget.borderColor!
                                              : widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                        ),
                                        left: BorderSide(
                                          width: 1.0,
                                          color: widget.borderColor != null
                                              ? widget.borderColor!
                                              : widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                        ),
                                        right: BorderSide(
                                          width: 1.0,
                                          color: widget.borderColor != null
                                              ? widget.borderColor!
                                              : widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                        ),
                                        bottom: BorderSide(
                                          width: 1.0,
                                          color: widget.borderColor != null
                                              ? widget.borderColor!
                                              : widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                        ),
                                      )
                                    : Border(),
                                borderRadius: widget.filled!
                                    ? BorderRadius.only(
                                        topLeft: Radius.circular(35),
                                        topRight: Radius.circular(35),
                                        bottomLeft: Radius.circular(35),
                                        bottomRight: Radius.circular(35))
                                    : BorderRadius.only(
                                        topRight: Radius.circular(42),
                                        bottomLeft: Radius.circular(42),
                                        bottomRight: Radius.circular(42),
                                        topLeft: Radius.circular(42)),
                              ),
                              padding: EdgeInsets.symmetric(
                                  horizontal: 12, vertical: 12),
                              child: widget.loading!
                                  ? Container(
                                      padding: EdgeInsets.symmetric(
                                          horizontal: 27, vertical: 2),
                                      child: SizedBox(
                                        height: 24,
                                        width: 24,
                                        child: widget.fullScreen!
                                            ? Center(
                                                child:
                                                    CircularProgressIndicator(
                                                  backgroundColor: widget
                                                          .filled!
                                                      ? kLightNeutralLighten0
                                                      : widget.color,
                                                  valueColor:
                                                      AlwaysStoppedAnimation<
                                                              Color>(
                                                          widget.filled!
                                                              ? widget.color
                                                              : Colors.white),
                                                  // strokeWidth: 2,
                                                ),
                                              )
                                            : CircularProgressIndicator(
                                                backgroundColor:
                                                    widget.indicatorColor !=
                                                            null
                                                        ? widget.indicatorColor!
                                                        : kLightNeutralLighten0,
                                                valueColor: AlwaysStoppedAnimation<
                                                        Color>(
                                                    widget.indicatorValueColor !=
                                                            null
                                                        ? widget
                                                            .indicatorValueColor!
                                                        : widget.color),
                                              ),
                                      ),
                                    )
                                  : Row(
                                      mainAxisSize: MainAxisSize.min,
                                      mainAxisAlignment: widget.fullScreen!
                                          ? MainAxisAlignment.center
                                          : MainAxisAlignment.start,
                                      children: [
                                        widget.icon != ''
                                            ? Image.asset(widget.icon!,
                                                scale: 2.3,
                                                color: widget.filled!
                                                    ? kPrimaryLighten0
                                                    : !widget.filled! &&
                                                            widget.disabled
                                                        ? kDarkNeutralLighten4
                                                        : widget.color)
                                            : SizedBox(),
                                        widget.icon != ''
                                            ? SizedBox(
                                                width: 11,
                                              )
                                            : SizedBox(),
                                        Flexible(
                                          child: Text(
                                            widget.text!,
                                            textAlign: TextAlign.center,
                                            style: TextStyle(
                                                color: widget.disabled &&
                                                        widget.filled!
                                                    ? kLightNeutralLighten0
                                                    : widget.disabled &&
                                                            !widget.filled!
                                                        ? kDarkNeutralLighten4
                                                        : widget.filled!
                                                            ? widget.textColor
                                                            : widget.color,
                                                fontSize: widget.fontSize ?? 16,
                                                fontWeight: FontWeight.w500,
                                                fontFamily: "Poppins",
                                                decoration:
                                                    TextDecoration.none),
                                          ),
                                        )
                                      ],
                                    ),
                            )
                          : widget.size == ButtonSize.XLARGE
                              ? Container(
                                  // width: w * 0.42,
                                  // height: h * 0.096,
                                  width: widget.fullScreen! ? w : null,
                                  decoration: BoxDecoration(
                                    color: !widget.disabled &&
                                            widget.filled! &&
                                            (widget.color != kPrimaryBase ||
                                                widget.color != kSuccessBase ||
                                                widget.color != kWarningBase ||
                                                widget.color != kSuccessBase ||
                                                widget.color != kAccentBase)
                                        ? widget.color
                                        : widget.disabled &&
                                                widget.color == kPrimaryBase &&
                                                widget.filled!
                                            ? kDarkNeutralLighten2
                                            : widget.disabled &&
                                                    widget.color ==
                                                        kSuccessBase &&
                                                    widget.filled!
                                                ? kSuccessLighten2
                                                : widget.disabled &&
                                                        widget.color ==
                                                            kAccentBase &&
                                                        widget.filled!
                                                    ? kAccentLighten2
                                                    : widget.disabled &&
                                                            widget.color ==
                                                                kWarningBase &&
                                                            widget.filled!
                                                        ? kWarningLighten2
                                                        : widget.disabled &&
                                                                widget.color ==
                                                                    kErrorBase &&
                                                                widget.filled!
                                                            ? kErrorLighten2
                                                            : widget.filled! &&
                                                                    widget
                                                                        .hasBeenPressed!
                                                                ? widget.color
                                                                : widget.color ==
                                                                            kPrimaryBase &&
                                                                        widget
                                                                            .filled! &&
                                                                        !widget
                                                                            .hasBeenPressed!
                                                                    ? kPrimaryDarken4
                                                                    : widget.color ==
                                                                                kSuccessBase &&
                                                                            widget
                                                                                .filled! &&
                                                                            !widget
                                                                                .hasBeenPressed!
                                                                        ? kSuccessDarken4
                                                                        : widget.color == kAccentBase &&
                                                                                widget.filled! &&
                                                                                !widget.hasBeenPressed!
                                                                            ? kAccentDarken4
                                                                            : widget.color == kWarningBase && widget.filled! && !widget.hasBeenPressed!
                                                                                ? kWarningDarken4
                                                                                : widget.color == kErrorBase && widget.filled! && !widget.hasBeenPressed!
                                                                                    ? kErrorDarken4
                                                                                    : widget.filled! && widget.disabled
                                                                                        ? kDarkNeutralLighten2
                                                                                        : Colors.transparent,
                                    border: widget.border!
                                        ? Border(
                                            top: BorderSide(
                                              width: 1.0,
                                              color: widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                            ),
                                            left: BorderSide(
                                              width: 1.0,
                                              color: widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                            ),
                                            right: BorderSide(
                                              width: 1.0,
                                              color: widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                            ),
                                            bottom: BorderSide(
                                              width: 1.0,
                                              color: widget.disabled &&
                                                      !widget.filled!
                                                  ? kDarkNeutralLighten4
                                                  : widget.color,
                                            ),
                                          )
                                        : Border(),
                                    borderRadius: widget.filled!
                                        ? BorderRadius.only(
                                            topLeft: Radius.circular(35),
                                            topRight: Radius.circular(35),
                                            bottomLeft: Radius.circular(35),
                                            bottomRight: Radius.circular(35))
                                        : BorderRadius.only(
                                            topRight: Radius.circular(44),
                                            bottomLeft: Radius.circular(44),
                                            bottomRight: Radius.circular(44),
                                            topLeft: Radius.circular(44)),
                                  ),
                                  padding: EdgeInsets.symmetric(
                                      horizontal: 12, vertical: 12),
                                  child: widget.loading!
                                      ? Container(
                                          padding: EdgeInsets.symmetric(
                                              horizontal: 27, vertical: 2),
                                          child: SizedBox(
                                            height: 24,
                                            width: 24,
                                            child: widget.fullScreen!
                                                ? Center(
                                                    child:
                                                        CircularProgressIndicator(
                                                      backgroundColor: widget
                                                                  .indicatorColor !=
                                                              null
                                                          ? widget
                                                              .indicatorColor!
                                                          : kLightNeutralLighten0,
                                                      valueColor: AlwaysStoppedAnimation<
                                                          Color>(widget
                                                                  .indicatorValueColor !=
                                                              null
                                                          ? widget
                                                              .indicatorValueColor!
                                                          : widget.color),
                                                    ),
                                                  )
                                                : CircularProgressIndicator(
                                                    backgroundColor: widget
                                                                .indicatorColor !=
                                                            null
                                                        ? widget.indicatorColor!
                                                        : kLightNeutralLighten0,
                                                    valueColor: AlwaysStoppedAnimation<
                                                        Color>(widget
                                                                .indicatorValueColor !=
                                                            null
                                                        ? widget
                                                            .indicatorValueColor!
                                                        : widget.color),
                                                  ),
                                          ),
                                        )
                                      : Row(
                                          mainAxisSize: MainAxisSize.min,
                                          mainAxisAlignment: widget.fullScreen!
                                              ? MainAxisAlignment.center
                                              : MainAxisAlignment.start,
                                          children: [
                                            widget.icon != ''
                                                ? Image.asset(widget.icon!,
                                                    scale: 2.3,
                                                    color: widget.filled!
                                                        ? kPrimaryLighten0
                                                        : !widget.filled! &&
                                                                widget.disabled
                                                            ? kDarkNeutralLighten4
                                                            : widget.color)
                                                : SizedBox(),
                                            widget.icon != ''
                                                ? SizedBox(
                                                    width: 11,
                                                  )
                                                : SizedBox(),
                                            Flexible(
                                              child: Text(
                                                widget.text!,
                                                textAlign: TextAlign.center,
                                                style: TextStyle(
                                                    color: widget.disabled &&
                                                            widget.filled!
                                                        ? kLightNeutralLighten0
                                                        : widget.disabled &&
                                                                !widget.filled!
                                                            ? kDarkNeutralLighten4
                                                            : widget.filled!
                                                                ? widget
                                                                    .textColor
                                                                : widget.color,
                                                    fontSize:
                                                        widget.fontSize ?? 18,
                                                    fontWeight: FontWeight.w500,
                                                    fontFamily: "Poppins",
                                                    decoration:
                                                        TextDecoration.none),
                                              ),
                                            )
                                          ],
                                        ),
                                )
                              : Container(),
    );
  }
}
