import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class ChipsAvatar extends StatelessWidget {
  final Color? chipColor, avatarColor;
  final String? username, profileImageUrl;
  ImageProvider? profileDecorImgType;

  ChipsAvatar({
    this.chipColor,
    this.avatarColor,
    this.profileImageUrl,
    this.username,
    this.profileDecorImgType,
  });

  @override
  Widget build(BuildContext context) {
    Widget _profileImage(String name, String image) {
      var nameInitial = name[0].toUpperCase();

      //if user uploads an image the initials vanish
      if (image.length > 0) {
        nameInitial = '';
      }
      return Container(
        decoration: BoxDecoration(
          color: avatarColor,
          borderRadius: BorderRadius.circular(100.0),
          image: DecorationImage(
              image: profileDecorImgType ?? NetworkImage(image)),
        ),
        child: Center(
          child: Text(
            nameInitial,
            style: TextStyle(
              fontFamily: 'Proxima Nova',
              color: avatarColor == kErrorLighten5 ||
                      avatarColor == kWarningLighten5 ||
                      avatarColor == kPrimaryLighten5 ||
                      avatarColor == kAccentLighten5 ||
                      avatarColor == kSuccessLighten5 ||
                      avatarColor == kPrimaryLighten5
                  ? kDarkNeutralBase
                  : kLightNeutralBase,
              fontWeight: FontWeight.w700,
            ),
          ),
        ),
      );
    }

    return Chip(
      padding: EdgeInsets.symmetric(horizontal: 4, vertical: 4.0),
      label: Text(
        username!,
        style: TextStyle(
            color: chipColor == kErrorLighten5
                ? kErrorBase
                : chipColor == kSuccessLighten5
                    ? kSuccessBase
                    : chipColor == kAccentLighten5
                        ? kAccentBase
                        : chipColor == kWarningLighten5
                            ? kWarningBase
                            : chipColor == kPrimaryBase
                                ? kLightNeutralLighten0
                                : chipColor == kSuccessBase
                                    ? kLightNeutralLighten0
                                    : chipColor == kWarningBase
                                        ? kLightNeutralLighten0
                                        : chipColor == kAccentBase
                                            ? kLightNeutralLighten0
                                            : chipColor == kErrorBase
                                                ? kLightNeutralLighten0
                                                : kPrimaryBase,
            fontFamily: 'Proxima Nova',
            fontWeight: FontWeight.w600),
      ),
      avatar: CircleAvatar(
        child: _profileImage(username!, profileImageUrl!),
      ),
      backgroundColor: chipColor ??
          (RothkoCache.getTheme!(context) == ThemeMode.light
              ? kDarkNeutralBase
              : kLightNeutralLighten5),
    );
  }
}
