import 'package:flutter/material.dart';
import 'package:date_format/date_format.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class TimePicker extends StatefulWidget {
  final int? maxlength;

  TimePicker({this.maxlength});
  @override
  _TimePickerState createState() => _TimePickerState();
}

const MaterialColor _timePickerColor = MaterialColor(0xFF0047CC, <int, Color>{
  50: Color(0xFF0047CC),
  100: Color(0xFF0047CC),
  200: Color(0xFF0047CC),
  300: Color(0xFF0047CC),
  400: Color(0xFF0047CC),
  500: Color(0xFF0047CC),
  600: Color(0xFF0047CC),
  700: Color(0xFF0047CC),
  800: Color(0xFF0047CC),
  900: Color(0xFF0047CC)
});

class _TimePickerState extends State<TimePicker> {
  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    // setState(() {
    //   FocusScope.of(context).requestFocus(_labelFocusNode);
    // });

    _selectTime(BuildContext context) async {
      final TimeOfDay picked = (await showTimePicker(
        builder: (BuildContext context, Widget? child) {
          return Theme(
            // data: ThemeData.dark(), // This will change to light theme.
            data: ThemeData(
              primarySwatch: _timePickerColor,
            ),
            child: child!,
          );
        },
        context: context,
        initialTime: selectedTime,
      ))!;

      if (picked != null)
        setState(() {
          selectedTime = picked;
          _hour = selectedTime.hour.toString();
          _minute = selectedTime.minute.toString();
          _time = _hour! + ' : ' + _minute!;
          _timeController.text = _time!;
          _timeController.text = formatDate(
              DateTime(2019, 08, 1, selectedTime.hour, selectedTime.minute),
              [hh, ':', nn, " ", am]).toString();
        });
    }

    _selectTime(context);
  }

  double? h;
  double? w;

  String? _hour, _minute, _time;

  String? dateTime;

  DateTime selectedDate = DateTime.now();

  TimeOfDay selectedTime = TimeOfDay(hour: 00, minute: 00);

  TextEditingController _timeController = TextEditingController();

  _selectTime(BuildContext context) async {
    final TimeOfDay picked = (await showTimePicker(
      context: context,
      initialTime: selectedTime,
    ))!;
    if (picked != null)
      setState(() {
        selectedTime = picked;
        _hour = selectedTime.hour.toString();
        _minute = selectedTime.minute.toString();
        _time = _hour! + ' : ' + _minute!;
        _timeController.text = _time!;
        _timeController.text = formatDate(
            DateTime(2019, 08, 1, selectedTime.hour, selectedTime.minute),
            [hh, ':', nn, " ", am]).toString();
      });
  }

  FocusNode? _labelFocusNode;

  Color fillColor = kLightNeutralLighten5;
  TextEditingController _textfieldController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    double w = MediaQuery.of(context).size.width;
    double h = MediaQuery.of(context).size.height;
    String type;
    return Scaffold(
      body: Center(
        child: Padding(
          padding: EdgeInsets.all(15),
          child: TextFormField(
            maxLength: widget.maxlength,
            maxLengthEnforced: false,
            readOnly: true,

            controller: _textfieldController,
            cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                ? kDarkNeutralBase
                : kLightNeutralBase,
            cursorHeight: 24.0,
            // focusNode: _labelFocusNode,
            onTap: _requestFocus,
            style: TextStyle(
                color: RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kDarkNeutralBase
                    : kLightNeutralBase,
                fontFamily: 'Proxima Nova',
                fontSize: 16.0,
                fontWeight: FontWeight.w400),
            decoration: InputDecoration(
                prefixIcon: new Padding(
                  padding: const EdgeInsets.only(
                      top: 15, left: 5, right: 0, bottom: 15),
                  child: new SizedBox(
                    height: 4,
                    child: Image.asset('assets/img/calendar-outline.png'),
                  ),
                ),
                errorBorder: UnderlineInputBorder(
                    borderSide: BorderSide(color: kErrorBase)),
                focusedBorder: UnderlineInputBorder(
                    borderRadius: BorderRadius.circular(4.0),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
                contentPadding: EdgeInsets.only(bottom: 16.0, left: 16.0),
                fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        !_labelFocusNode!.hasFocus
                    ? kLightNeutralLighten5
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            _labelFocusNode!.hasFocus
                        ? kLightNeutralLighten4
                        : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                !_labelFocusNode!.hasFocus
                            ? kDarkNeutralBase
                            : kDarkNeutralLighten1,
                filled: true,
                // helperText: widget.helperHint,
                helperStyle: TextStyle(
                    fontSize: 10.0,
                    color: kDarkNeutralLighten3,
                    fontFamily: 'Proxima Nova'),
                suffixIcon: Padding(
                  padding: EdgeInsets.only(top: 5.0),
                  child: Icon(
                    Icons.keyboard_arrow_down,
                    size: 24.0,
                    color: RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kDarkNeutralLighten3
                        : kPrimaryLighten3,
                  ),
                ),
                // hintText: " ${selectedTime.hour}:${selectedTime.minute}",

                hintText: !_labelFocusNode!.hasFocus
                    ? "${selectedTime.hour}:${selectedTime.minute}"
                    : "",
                labelText: !_labelFocusNode!.hasFocus
                    ? "Time"
                    : "${selectedTime.hour}:${selectedTime.minute}",
                labelStyle: TextStyle(
                    height: _labelFocusNode!.hasFocus ? 1.0 : 1.6,
                    fontSize: 16.0,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                                !_labelFocusNode!.hasFocus ||
                            _labelFocusNode!.hasFocus
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
                border: UnderlineInputBorder(
                    borderRadius: BorderRadius.circular(4.0),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2))),
          ),
        ),
      ),
    );
  }
}
