import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class SearchBox extends StatefulWidget {
  final String? label, hint;

  bool? readOnly, enabled;

  final TextEditingController? textCtrl;

  SearchBox(
      {@required this.label,
      @required this.readOnly,
      @required this.enabled,
      this.textCtrl,
      this.hint});
  TextEditingController _textfieldController = TextEditingController();
  @override
  _SearchBoxState createState() => _SearchBoxState();
}

class _SearchBoxState extends State<SearchBox> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return Ink(
      child: InkWell(
        child: Container(
          width: 320.0,
          height: 76.0,
          child: TextFormField(
            maxLengthEnforced: false,
            enabled: widget.enabled,
            readOnly: widget.readOnly!,
            controller: widget.textCtrl ?? widget._textfieldController,
            cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                ? kDarkNeutralBase
                : kLightNeutralBase,
            cursorHeight: 24.0,
            focusNode: _labelFocusNode,
            onTap: _requestFocus,
            style: TextStyle(
                color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        widget.enabled!
                    ? kDarkNeutralBase
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !widget.enabled!
                        ? kDarkNeutralLighten4
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                !widget.enabled!
                            ? kPrimaryLighten3
                            : kLightNeutralBase,
                fontFamily: 'Proxima Nova',
                fontSize: 16.0,
                fontWeight: FontWeight.w400),
            decoration: InputDecoration(
              errorStyle: TextStyle(color: kErrorBase),
              errorBorder: UnderlineInputBorder(
                  borderSide: BorderSide(color: kErrorBase)),
              focusedBorder: UnderlineInputBorder(
                  borderSide: BorderSide(
                      color: RothkoCache.getTheme!(context) == ThemeMode.light
                          ? kLightNeutralLighten1
                          : kDarkNeutralLighten2)),
              fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                      !_labelFocusNode!.hasFocus
                  ? kLightNeutralLighten5
                  : RothkoCache.getTheme!(context) == ThemeMode.light &&
                          _labelFocusNode!.hasFocus &&
                          widget.enabled!
                      ? kLightNeutralLighten4
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              !_labelFocusNode!.hasFocus
                          ? kDarkNeutralBase
                          : kDarkNeutralLighten1,
              filled: true,
              hintText: widget.hint,
              helperStyle: TextStyle(
                  fontSize: 10.0,
                  color: kDarkNeutralLighten3,
                  fontFamily: 'Proxima Nova'),
              suffixIcon: Image.asset(
                'assets/img/search.png',
                scale: 2.4,
              ),
              labelText: widget.label,
              labelStyle: TextStyle(
                  fontSize: _labelFocusNode!.hasFocus ? 10.0 : 16.0,
                  fontFamily: 'Proxima Nova',
                  color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                          !_labelFocusNode!.hasFocus &&
                          widget.enabled!
                      ? kDarkNeutralBase
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              _labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kDarkNeutralLighten3
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  !_labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kLightNeutralBase
                              : kPrimaryLighten3),
              enabledBorder: UnderlineInputBorder(
                  borderSide: BorderSide(
                      color: RothkoCache.getTheme!(context) == ThemeMode.light
                          ? kLightNeutralLighten1
                          : kDarkNeutralLighten2)),
              border: UnderlineInputBorder(
                  borderSide: BorderSide(
                      color: RothkoCache.getTheme!(context) == ThemeMode.light
                          ? kLightNeutralLighten1
                          : kDarkNeutralLighten2)),
            ),
          ),
        ),
        onTap: () {
          setState(() {
            fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
                ? kLightNeutralLighten4
                : kLightNeutralLighten1;
          });
        },
      ),
    );
  }
}
