import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class SelectDefaultDynamic<T> extends StatefulWidget {
  final List<T> options;
  final BuildContext? context;
  final void Function(T?)? onChanged;
  final T? selected;
  final String? hintText;
  final Widget? suffixIcon;
  final bool? networkIcons;
  final bool? hasIcons;
  final String? labelText;
  final Color? labelTextColor;
  final String? Function(T?)? validator;
  final String Function(T?) getText;
  final String Function(T?)? getIcons;
  final AutovalidateMode? autovalidateMode;
  bool? enabled;
  Function()? onTap;
  bool? readonly;
  final double? labelTextSize, width;
  bool? focused;
  final BorderSide? customBorder;

  SelectDefaultDynamic(
      {required this.options,
      required this.getText,
      this.context,
      this.getIcons,
      this.hasIcons = false,
      this.networkIcons = false,
      this.onChanged,
      this.autovalidateMode,
      this.selected,
      this.hintText,
      this.focused = false,
      this.readonly = false,
      this.onTap,
      this.enabled = true,
      this.suffixIcon,
      this.labelText,
      this.labelTextColor,
      this.validator,
      this.labelTextSize,
      this.customBorder,
      this.width})
      : assert(hasIcons! ? getIcons != null : true);
  @override
  _SelectDefaultDynamicState createState() => _SelectDefaultDynamicState<T>();
}

class _SelectDefaultDynamicState<T> extends State<SelectDefaultDynamic> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  bool isFocused = false;
  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    requestFocus();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void requestFocus() {
    if (widget.selected != null) {
      setState(() {
        isFocused = true;
        widget.focused = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.9,
      height: 80,
      child: Stack(
        children: [
          DropdownButtonFormField<T>(
            autovalidateMode: widget.autovalidateMode,
            validator: (x) {
              widget.validator?.call(x);
            },
            isExpanded: true,
            items: widget.options.map<DropdownMenuItem<T>>((f) {
              return DropdownMenuItem<T>(
                onTap: widget.onTap,
                child: widget.hasIcons!
                    ? Row(
                        children: [
                          widget.networkIcons!
                              ? Image.network('${widget.getIcons!(f)}')
                              : Image.asset('${widget.getIcons!(f)}.png'),
                          SizedBox(width: 15),
                          Text(
                            '${widget.getText(f)}',
                            style: TextStyle(
                                overflow: TextOverflow.ellipsis,
                                color: widget.enabled! &&
                                        RothkoCache.getTheme!(context) ==
                                            ThemeMode.light
                                    ? kDarkNeutralDarken4
                                    : !widget.enabled! &&
                                            RothkoCache.getTheme!(context) ==
                                                ThemeMode.light
                                        ? kDarkNeutralLighten3
                                        : kLightNeutralLighten5,
                                fontSize: widget.labelTextSize ?? 14),
                          ),
                        ],
                      )
                    : Text(
                        '${widget.getText(f)}',
                        style: TextStyle(
                            overflow: TextOverflow.ellipsis,
                            color: widget.enabled! &&
                                    RothkoCache.getTheme!(context) ==
                                        ThemeMode.light
                                ? kDarkNeutralDarken4
                                : !widget.enabled! &&
                                        RothkoCache.getTheme!(context) ==
                                            ThemeMode.light
                                    ? kDarkNeutralLighten3
                                    : kLightNeutralLighten5,
                            fontSize: widget.labelTextSize ?? 14),
                      ),
                value: f,
              );
            }).toList(),
            onChanged: widget.enabled! && widget.readonly == false
                ? (x) {
                    widget.onChanged?.call(x);
                  }
                : null,
            value: widget.selected,
            onTap: () {
              setState(() {
                isFocused = true;
                widget.focused = true;
              });
            },
            decoration: InputDecoration(
                hintText: widget.hintText,
                enabled: widget.enabled!,
                filled: true,
                fillColor: widget.focused! &&
                        RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kLightNeutralLighten4
                    : !widget.focused! &&
                            RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kLightNeutralLighten5
                        : kDarkNeutralBase,
                border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : kDarkNeutralLighten2)),
                errorStyle: TextStyle(color: kErrorBase),
                errorBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(color: kErrorBase)),
                enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            style: BorderStyle.solid,
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : kLightNeutralLighten5)),
                focusedBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            style: BorderStyle.solid,
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : Colors.red)),
                contentPadding:
                    const EdgeInsets.symmetric(vertical: 17.0, horizontal: 13.0),
                hintStyle: TextStyle(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light && !_labelFocusNode!.hasFocus && widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light && _labelFocusNode!.hasFocus && widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) == ThemeMode.dark && !_labelFocusNode!.hasFocus && widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3,
                    fontFamily: 'Proxima Nova',
                    fontSize: 16,
                    fontWeight: FontWeight.w400),
                labelStyle: TextStyle(
                  fontFamily: 'Proxima Nova',
                  fontSize: 16,
                  fontWeight: FontWeight.w400,
                  color: widget.labelTextColor,
                )),
            icon: widget.suffixIcon,
          ),
          Positioned(
              left: 13,
              top: isFocused
                  ? 7
                  : isFocused && widget.hasIcons!
                      ? 4
                      : 18,
              child: Text(
                widget.labelText!,
                style: TextStyle(
                    fontSize: isFocused ? 10 : 14,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
              ))
        ],
      ),
    );
  }
}
