import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class DenseDefault extends StatefulWidget {
  final List<String>? options;
  final BuildContext? context;
  final void Function(String?)? onChanged;
  final String? selected;
  final String? hintText;
  final Widget? suffixIcon;
  final String? labelText;
  final Color? labelTextColor;
  final String? Function(String?)? validator;

  final double? labelTextSize;
  bool? focused;
  bool? enabled;
  bool? readonly;
  final BorderSide? customBorder;

  final AutovalidateMode? autovalidateMode;

  DenseDefault(
      {@required this.options,
      this.context,
      this.onChanged,
      this.selected,
      this.hintText,
      this.focused = false,
      this.autovalidateMode,
      this.readonly = false,
      this.enabled = true,
      this.suffixIcon,
      this.labelText,
      this.labelTextColor,
      this.validator,
      this.labelTextSize,
      this.customBorder});
  @override
  _DenseDefaultState createState() => _DenseDefaultState();
}

class _DenseDefaultState extends State<DenseDefault> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  bool isFocused = false;

  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    requestFocus();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void requestFocus() {
    if (widget.selected != null ) {
      setState(() {
        isFocused = true;
        widget.focused = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.9,
      height: 55,
      padding: EdgeInsets.only(top: widget.enabled! ? 10 : 0),
      child: Stack(
        children: [
          DropdownButtonFormField(
            autovalidateMode: widget.autovalidateMode,
            validator: widget.validator,
            items: widget.options!.map((String f) {
              return DropdownMenuItem(
                child: Text(
                  '$f',
                  style: TextStyle(
                      color: widget.enabled! &&
                              RothkoCache.getTheme!(context) == ThemeMode.light
                          ? kDarkNeutralDarken4
                          : !widget.enabled! &&
                                  RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                              ? kDarkNeutralLighten3
                              : kLightNeutralLighten5,
                      fontSize: widget.labelTextSize ?? 14),
                ),
                value: f,
              );
            }).toList(),
            onChanged: widget.enabled! && widget.readonly! == false
                ? widget.onChanged
                : null,
            value: widget.selected,
            isDense: true,
            onTap: () {
              setState(() {
                isFocused = true;
                widget.focused = true;
              });
            },
            decoration: InputDecoration(
                enabled: widget.enabled!,
                filled: true,
                fillColor: widget.focused! &&
                        RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kLightNeutralLighten4
                    : !widget.focused! &&
                            RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kLightNeutralLighten5
                        : kDarkNeutralLighten2,
                border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : kDarkNeutralLighten2)),
                enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            style: BorderStyle.solid,
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : kDarkNeutralLighten2)),
                errorStyle: TextStyle(color: kErrorBase),
                errorBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(color: kErrorBase)),
                focusedBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            style: BorderStyle.solid,
                            color:
                                RothkoCache.getTheme!(context) == ThemeMode.light
                                    ? kLightNeutralLighten1
                                    : Colors.red)),
                contentPadding:
                    const EdgeInsets.symmetric(vertical: 7.0, horizontal: 13.0),
                hintStyle: TextStyle(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light && !_labelFocusNode!.hasFocus && widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light && _labelFocusNode!.hasFocus && widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) == ThemeMode.dark && !_labelFocusNode!.hasFocus && widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3,
                    fontFamily: 'Proxima Nova',
                    fontSize: 16,
                    fontWeight: FontWeight.w400),
                labelStyle: TextStyle(
                  fontFamily: 'Proxima Nova',
                  fontSize: 16,
                  height: _labelFocusNode!.hasFocus ? 2.0 : .9,
                  fontWeight: FontWeight.w400,
                  color: widget.labelTextColor,
                )),
            iconSize: 19,
            icon: widget.suffixIcon,
          ),
          Positioned(
              left: 13,
              top: isFocused ? 4 : 14,
              child: Text(
                widget.labelText!,
                style: TextStyle(
                    fontSize: isFocused ? 10 : 14,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
              ))
        ],
      ),
    );
  }
}
