import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/widgets/theme/theme_mode_provider.dart';

class IconsDefault extends StatefulWidget {
  final List<String>? options;
  final BuildContext? context;
  final void Function(String?)? onChanged;
  final String? selected;
  final String? hintText;
  final Widget? suffixIcon;
  final Widget? prefix;
  final String? labelText;
  final Color? labelTextColor;
  final String? Function(String?)? validator;
  AutovalidateMode? autovalidateMode;
  bool? enabled;
  bool? readonly;
  final double? labelTextSize;
  bool? focused;
  final BorderSide? customBorder;

  IconsDefault(
      {@required this.options,
      this.context,
      this.onChanged,
      this.selected,
      this.hintText,
      this.focused = false,
      this.readonly = false,
      this.enabled = true,
      this.suffixIcon,
      this.labelText,
      this.autovalidateMode,
      this.labelTextColor,
      this.validator,
      this.labelTextSize,
      this.customBorder,
      this.prefix});
  @override
  _IconsDefaultState createState() => _IconsDefaultState();
}

class _IconsDefaultState extends State<IconsDefault> {
  Color fillColor = kLightNeutralLighten5;
  FocusNode? _labelFocusNode;
  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    requestFocus();
  }

  bool isFocused = false;

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void requestFocus() {
    if (widget.selected != null) {
      setState(() {
        isFocused = true;
        widget.focused = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 320,
      height: 60,
      decoration: BoxDecoration(
        border: Border.all(
          style: BorderStyle.solid,
          color: kLightNeutralLighten1,
        ),
        borderRadius: BorderRadius.circular(8),
        color:
            widget.focused! && RothkoCache.getTheme!(context) == ThemeMode.light
                ? kLightNeutralDarken1
                : !widget.focused! &&
                        RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kLightNeutralBase
                    : kDarkNeutralLighten2,
      ),
      child: Row(
        children: [
          SizedBox(
            width: 5,
          ),
          widget.prefix ??
              Icon(
                Icons.location_on_outlined,
                color: kDarkNeutralLighten3,
              ),
          Padding(
            padding: const EdgeInsets.only(bottom: 0.0),
            child: Container(
              width: 280,
              height: 50,
              child: Stack(
                children: [
                  DropdownButtonFormField(
                    autovalidateMode: widget.autovalidateMode,
                    validator: widget.validator,
                    items: widget.options!.map((String f) {
                      return DropdownMenuItem(
                        child: Text(
                          '$f',
                          style: TextStyle(
                              color: widget.enabled! &&
                                      RothkoCache.getTheme!(context) ==
                                          ThemeMode.light
                                  ? kDarkNeutralDarken4
                                  : !widget.enabled! &&
                                          RothkoCache.getTheme!(context) ==
                                              ThemeMode.light
                                      ? kDarkNeutralLighten3
                                      : kLightNeutralLighten5,
                              fontSize: widget.labelTextSize ?? 14),
                        ),
                        value: f,
                      );
                    }).toList(),
                    onChanged: widget.enabled! && widget.readonly == false
                        ? widget.onChanged
                        : null,
                    value: widget.selected,
                    onTap: () {
                      setState(() {
                        isFocused = true;
                        widget.focused = true;
                      });
                    },
                    decoration: InputDecoration(
                        enabled: widget.enabled!,
                        filled: true,
                        fillColor: widget.focused! &&
                                RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                            ? kLightNeutralDarken1
                            : !widget.focused! &&
                                    RothkoCache.getTheme!(context) ==
                                        ThemeMode.light
                                ? kLightNeutralBase
                                : kDarkNeutralLighten2,
                        errorStyle: TextStyle(color: kErrorBase),
                        errorBorder: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(8),
                            borderSide: BorderSide(color: kErrorBase)),
                        enabledBorder: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(8),
                            borderSide: widget.customBorder ??
                                BorderSide(
                                    style: BorderStyle.solid,
                                    color: Colors.transparent)),
                        focusedBorder: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(8),
                            borderSide: widget.customBorder ??
                                BorderSide(
                                    style: BorderStyle.solid,
                                    color: Colors.transparent)),
                        contentPadding: EdgeInsets.symmetric(horizontal: 17.0),
                        hintStyle: TextStyle(
                            color: RothkoCache.getTheme!(context) ==
                                        ThemeMode.light &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kDarkNeutralLighten3
                                : RothkoCache.getTheme!(context) ==
                                            ThemeMode.light &&
                                        _labelFocusNode!.hasFocus &&
                                        widget.enabled!
                                    ? kDarkNeutralLighten3
                                    : RothkoCache.getTheme!(context) ==
                                                ThemeMode.dark &&
                                            !_labelFocusNode!.hasFocus &&
                                            widget.enabled!
                                        ? kLightNeutralBase
                                        : kPrimaryLighten3,
                            fontFamily: 'Proxima Nova',
                            fontSize: 16,
                            fontWeight: FontWeight.w400),
                        labelStyle: TextStyle(
                          fontFamily: 'Proxima Nova',
                          fontSize: 16,
                          fontWeight: FontWeight.w400,
                          color: widget.labelTextColor,
                        )),
                    icon: widget.suffixIcon,
                  ),
                  Positioned(
                      left: 16,
                      top: isFocused ? 5 : 18,
                      child: Text(
                        widget.labelText!,
                        style: TextStyle(
                            fontSize: isFocused ? 10 : 14,
                            fontFamily: 'Proxima Nova',
                            color: RothkoCache.getTheme!(context) ==
                                        ThemeMode.light &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kDarkNeutralLighten3
                                : RothkoCache.getTheme!(context) ==
                                            ThemeMode.light &&
                                        _labelFocusNode!.hasFocus &&
                                        widget.enabled!
                                    ? kDarkNeutralLighten3
                                    : RothkoCache.getTheme!(context) ==
                                                ThemeMode.dark &&
                                            !_labelFocusNode!.hasFocus &&
                                            widget.enabled!
                                        ? kLightNeutralBase
                                        : kPrimaryLighten3),
                      ))
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
