import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/widgets/theme/theme_mode_provider.dart';

class TextFieldClearable extends StatefulWidget {
  final String? label, helperHint;
  bool? readOnly, enabled;
  final int? maxlength;
  final int? maxLines;
  final TextEditingController? textCtrl;
  ValueChanged<String>? onChanged;
  TextInputType? keyboardType;
  AutovalidateMode? autovalidateMode;

  bool enableSuggestions;
  String? Function(String?)? validator;
  List<TextInputFormatter>? inputFormatters;

  TextFieldClearable(
      {@required this.label,
      @required this.readOnly,
      @required this.enabled,
      this.helperHint,
      this.onChanged,
      this.inputFormatters,
      this.autovalidateMode,
      this.maxlength,
      this.maxLines,
      this.keyboardType,
      this.validator,
      this.enableSuggestions = false,
       this.textCtrl});
  @override
  _TextFieldClearableState createState() => _TextFieldClearableState();
}

class _TextFieldClearableState extends State<TextFieldClearable> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;
  TextEditingController _textfieldController = TextEditingController();
 bool isFocused = false;
  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    _labelFocusNode!.addListener(() {
      if (_labelFocusNode!.hasFocus) {
        setState(() {
          isFocused = true;
        });
        return;
      }
      setState(() {
        isFocused = false;
      });

    });
  }


  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return Ink(
      child: InkWell(
        child: Container(
          width: MediaQuery.of(context).size.width * 0.9,
          height: 76.0,
          child: Stack(
            children: [
              TextFormField(
                textAlign: TextAlign.start,
                autovalidateMode: widget.autovalidateMode,
                maxLength: widget.maxlength,
               maxLines: widget.maxLines,
                minLines: 1,
                 maxLengthEnforced: false,
                enabled: widget.enabled,
                enableSuggestions: widget.enableSuggestions,
                inputFormatters: widget.inputFormatters,
                keyboardType: widget.keyboardType,
                onChanged: widget.onChanged,
                validator: widget.validator,
                readOnly: widget.readOnly!,
                controller: widget.textCtrl ?? _textfieldController,
                cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kDarkNeutralBase
                    : kLightNeutralBase,
                cursorHeight: 24.0,
                focusNode: _labelFocusNode,
                onTap: _requestFocus,
                style: TextStyle(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            widget.enabled!
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                !widget.enabled!
                            ? kDarkNeutralLighten4
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !widget.enabled!
                                ? kPrimaryLighten3
                                : kLightNeutralBase,
                    fontFamily: 'Proxima Nova',
                    fontSize: 16.0,
                    fontWeight: FontWeight.w400),
                decoration: InputDecoration(
                    errorStyle: TextStyle(color: kErrorBase),
                    errorBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: BorderSide(color: kErrorBase)),
                    focusedBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: BorderSide(
                            color: RothkoCache.getTheme!(context) == ThemeMode.light
                                ? kLightNeutralLighten1
                                : kDarkNeutralLighten2)),
                    fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus
                        ? kLightNeutralLighten5
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kLightNeutralLighten4
                            : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus
                                ? kDarkNeutralBase
                                : kDarkNeutralLighten1,
                    filled: true,
                    helperText: widget.helperHint,
                    helperStyle: TextStyle(
                        fontSize: 10.0,
                        color: kDarkNeutralLighten3,
                        fontFamily: 'Proxima Nova'),
                    suffixIcon: IconButton(
                        onPressed: () {
                          _textfieldController.clear();
                        },
                        icon: Icon(
                          Icons.close,
                          size: 24.0,
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? kDarkNeutralLighten3
                                  : kPrimaryLighten3,
                        )),
                    labelStyle: TextStyle(
                        fontSize: _labelFocusNode!.hasFocus ? 10.0 : 16.0,
                        fontFamily: 'Proxima Nova',
                        color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                                !_labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralBase
                            : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                    _labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kDarkNeutralLighten3
                                : RothkoCache.getTheme!(context) ==
                                            ThemeMode.dark &&
                                        !_labelFocusNode!.hasFocus &&
                                        widget.enabled!
                                    ? kLightNeutralBase
                                    : kPrimaryLighten3),
                    enabledBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: BorderSide(
                            color: RothkoCache.getTheme!(context) == ThemeMode.light ? kLightNeutralLighten1 : kDarkNeutralLighten2)),
                    border: OutlineInputBorder(borderRadius: BorderRadius.circular(8), borderSide: BorderSide(color: RothkoCache.getTheme!(context) == ThemeMode.light ? kLightNeutralLighten1 : kDarkNeutralLighten2))),
              ),
              Positioned(
                  left: 13,
                  top: widget.textCtrl != null
                      ? widget.textCtrl!.text == ''
                          ? 17
                          : 3
                      : _textfieldController.text == ''
                          ? 17
                          : 3,
                  child: Text(
                   isFocused ? '' : widget.label!,
                    style: TextStyle(
                        fontSize: widget.textCtrl != null
                            ? widget.textCtrl!.text == ''
                                ? 14
                                : 10
                            : _textfieldController.text == ''
                                ? 14
                                :  10,
                        fontFamily: 'Proxima Nova',
                        color:
                            RothkoCache.getTheme!(context) == ThemeMode.light &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kDarkNeutralLighten3
                                : RothkoCache.getTheme!(context) ==
                                            ThemeMode.light &&
                                        _labelFocusNode!.hasFocus &&
                                        widget.enabled!
                                    ? kDarkNeutralLighten3
                                    : RothkoCache.getTheme!(context) ==
                                                ThemeMode.dark &&
                                            !_labelFocusNode!.hasFocus &&
                                            widget.enabled!
                                        ? kLightNeutralBase
                                        : kPrimaryLighten3),
                  ))
            ],
          ),
        ),
        onTap: () {
          setState(() {
            fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
                ? kLightNeutralLighten4
                : kLightNeutralLighten1;
          });
        },
      ),
    );
  }
}
