import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:provider/provider.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/widgets/route.dart';
import 'package:rothko_mobile/widgets/story.dart';
import 'package:rothko_mobile/widgets/story_page_wrapper.dart';
import 'package:rothko_mobile/widgets/theme/theme_mode_provider.dart';

class Storybook extends StatelessWidget {
  const Storybook({
    Key? key,
    this.children = const [],
    this.theme,
    this.darkTheme,
    this.themeMode = ThemeMode.system,
    this.localizationDelegates,
  }) : super(key: key);

  /// Theme override for the light theme.
  final ThemeData? theme;

  /// Theme override for the dark theme.
  final ThemeData? darkTheme;

  /// Indicates theme mode to use: light, dark or system.
  final ThemeMode? themeMode;

  /// Stories in the storybook.
  final List<Story>? children;

  /// Localizations Delegates override
  final List<LocalizationsDelegate>? localizationDelegates;

  @override
  Widget build(BuildContext context) => MultiProvider(
        providers: [
          Provider.value(value: children),
          ChangeNotifierProvider(create: (_) => ThemeModeProvider(themeMode!)),
        ],
        child: Builder(
          builder: (context) {
            return MaterialApp(
              debugShowCheckedModeBanner: false,
              themeMode: RothkoCache.getTheme!(context),
              theme: theme ??
                  ThemeData(
                      brightness: Brightness.light,
                      primaryColor: kPrimaryBase,
                      canvasColor: kLightNeutralBase),
              darkTheme: darkTheme ??
                  ThemeData(
                      brightness: Brightness.dark,
                      primaryColor: kDarkNeutralBase,
                      canvasColor: kDarkBackground,
                      cardColor: kDarkNeutralDarken2),
              localizationsDelegates: localizationDelegates,
              onGenerateRoute: (settings) => StoryRoute(
                settings: settings,
                builder: (_) {
                  return StoryPageWrapper(
                    children: children,
                    path: settings.name!.replaceFirst('/stories/', ''),
                  );
                },
              ),
            );
          },
        ),
      );
}
